﻿using System;

namespace Flyweight
{
    //사진 촬영 조건에 관한 열거형 정의
    public enum BodyType { EH_BA, EH_BB, EH_BC };
    public enum LensType { EH_L1, EH_L2, EH_L3 };
    public enum LightType { LT_CLEAR, LT_CLOUDY, LT_LAMP };

    class Meta //사진 파일들이 공유할 수 있는 촬영 조건을 정의한 클래스
    {
        static readonly string[] bodyname = { "EH_BA", "EH_BB", "EH_BC" };
        static readonly string[] lensname = { "EH_L1", "EH_L2", "EH_L3" };
        static readonly string[] lightname = { "맑음", "흐림", "램프" };

        //촬영 조건에 대한 속성들
        public BodyType Body { get; private set; }
        public LensType Lens { get; private set; }
        public LightType Light { get; private set; }

        readonly int seq; //일련번호
        static int scnt; //Meta 개체 수

        public Meta(BodyType body, LensType lens, LightType light)
        {
            scnt++;
            seq = scnt; //개체 생성 순으로 일련번호 부여
            Body = body;
            Lens = lens;
            Light = light;
        }

        // 촬영조건이 같은지 확인하는 메서드
        public bool IsEqual(BodyType body, LensType lens, LightType light)
        {
            return (Body == body) && (Lens == lens) && (Light == light);
        }

        public void View()
        {
            Console.WriteLine("일련번호:{0}", seq);
            Console.WriteLine("Body:{0}", bodyname[(int)Body]);
            Console.WriteLine("Lens:{0}", bodyname[(int)Lens]);
            Console.WriteLine("Light:{0}", bodyname[(int)Light]);
        }
    }
}
